/*---------------------------------------------------------------------------------------------------*\
|   PROGRAM NAME: incident_generic_name.sas                                                           |
|     Create incident generic-name summary table                                                      |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Version: Revised 1.0                                                                              |
|   Date: November 26, 2015                                                                           |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Program inputs:                                                                                   |
|       SAS dataset containing Generic Name Incident Episodes for each lookback period                |
|   Program outputs:                                                                                  |
|       SAS dataset containing summarized episodes for each stratification level                      |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Contact:                                                                                          |
|       Mini-Sentinel Coordinating Center                                                             |
|       info@mini-sentinel.org                                                                        |
\*---------------------------------------------------------------------------------------------------*/

/* Specify DrugCategory:  {GenericName | DrugClass} */
%let DrugCat = GenericName;

*** Call macro to summarize incident episodes for each stratification level;
%Incident_Rx_Summ
  ( InFile=DPtemp.RX_&DrugCat._Epi_LookBack ,  /* Input file prefix (Note: include libname)*/
    OutFile=DPLOCAL.Incident_Generic_Name ,    /* Output file name (Note: include libname)*/
    DrugCategory=&DrugCat ,                    /* Drug Category Name: {GenericName|DrugClass}*/
    DrugCategoryKey=&DrugCat.Key ,             /* Drug Category Key: {GenericNameKey|DrugClassKey}*/
    DEBUG=&DEBUG.                              /* Y/N flag for creating extra output (Default is N)*/
   ) ;

* End of incident_generic_name.sas;
