/***************************************************************************************************
*                                           MINI-SENTINEL PROGRAM
****************************************************************************************************
* NAME: qt_main_program.sas
*
* PURPOSE: Execute the summary table code
*
* MAJOR STEPS:
*
* KEY DEPENDENCIES/CONSTRAINTS/CAVEATS:
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO:
*  Mini-Sentinel Coordinating Center
*  info@mini-sentinel.org
*
*--------------------------------------------------------------------------------------------------
* HISTORY:
*  Create date (1/26/16):
*  Last modified date (1/26/16):
*  Version:
*
*  CHANGE LOG:
*
*   Version   Date       Comment (reference external documentation when available)
*   -------   --------   -------------------------------------------------------------------------
*   V2.0      1/26/16
*
**************************************************************************************************/

/* System options */
options nosymbolgen nomlogic ;

/*----------------------------------------------------------------------------*/
/* NOTE: Data Partner/Data Site programmer defines parameters in this section */
/*----------------------------------------------------------------------------*/

/* DEV Note: The SID ("Sample ID") macro variable needs to be removed from PROD */
/*           SID values:  50, 100k, 500k, 5m */
%let SID = 50;

/* Common Components include file parm - REQUIRED */
/* Example: //mini-sentinel/common-components/ms_common_components.sas */
%*let MSCC = edit-path/ms_common_components.sas;
%let MSCC = B:\mscdm\v4.0\etl01\sample_&SID.\common_components\ms_common_components.sas;

/* NOTES about intermediate, temporary files created by this package:                          */
/*   1) A DPtemp storage area is used for temporary files that need to persist across modules  */
/*      because all files in the WORK storage location are purged at start of each module.     */
/*   2) Files in the DPTemp storage area are purged when no longer needed.                     */
/*   3) At the completion of the package the DPTemp storage area is purged, so please          */
/*      do NOT assign DPtemp to any folder with permanent SAS!                                 */

/* DPtemp folder path parm - OPTIONAL (defaults to &DPLOCAL.DPtemp)                            */
/* By default, the DPtemp subdirectory is dynamically created under the DPLocal folder         */
/* and the parm value below will be dynamically set to &DPLOCAL.DPtemp                         */
%let DPtemp = ;   /* Leave blank to use default location, else specify an alternate location   */

/* NOTES about final summary tables:  */
/*  1) Individual tab delimited text files are automatically created.  */
/*  2) A MS Access database may optionally be requested. Whether it will be created depends    */
/*     on: A) Common-components macro variable _sas_access value indicating it is feasible.    */
/*         B) Absence of Windows/SAS compatibility issues (e.g. SAS PC Files Server might be required). */
/*  3) Any expected final SAS summary tables that are not found during export processing to other */
/*     data formats will generate a warning message which should trigger an investigation. */

/* ExportPath folder path parm - OPTIONAL (defaults to &DPLOCAL) */
/* The ExportPath may be pointed to an alternative path location but please think carefully */
/* before changing the default location (e.g. about ability to restore a copy of a specific version). */
/* By default, ExportPath will be dynamically set as follows: %let ExportPath = &DPLOCAL */
%let ExportPath=;  /* Leave blank for default location, else specify alternative location */

/* Access Files parm - OPTIONAL (defaults to N) */
/* Access files type (if any)  - Must be one of the following values: */
/*  N = No, do not generate Access files */
/*  M = Generate MDB format, compatible with Office version 2000, 2002, and 2003 */
/*  A = Generate ACCDB format, compatible with Office versions from 2007 and later; */
%let AccessFiles=N;

/* DBMS SAS export engine parm for MS Access - CONDITIONAL (required if AccessFiles requested) */
/* If required, it must be one of the following values: */
/*  ACCESSCS =  Used for translating between 32-bit MS Office Access and 64-bit SAS  */
/*              (Note: Requires installing/running SAS PC Files Server services for MS Windows.) */
/*    ACCESS =  Used for translating between 32-bit MS Office Access and 32-bit SAS  */
%let ACCESS_DBMS=;  /* Must be set appropriately if AccessFiles is set to M or A */


**************************************************************************************************
*******                                  END OF USER INPUT                                  ******
*******                             DO NOT EDIT BELOW THIS LINE                             ******
*******                        (Consult with MSOC or MS team leader                         ******
*******                           if you feel edits are required)                           ******
**************************************************************************************************;

/* Include Common Components */
%inc "&MSCC" /source ;

/*---------------------------------------------------------------------*/
/* NOTE: Programmer preparing Request-ID defines the                   */
/*       parameter MSReqID in coordination with the MSOC               */
/*---------------------------------------------------------------------*/

/*-------------------------------------------------------------------------------------------------
* Specific requests are made up a project-ID, workplan-type, workplan-ID, unique-dpid, version-ID
*--------------------------------------------------------------------------------------------------
*
*        If this is your request   . . . . .  then set parameter values as follows:
*   ---------------------------------     -------------------------------------------------------
*   [Task Order 7 - NME Dabigatran]       %let MSProjID = to07_nme_dabi ;
*   [WorkPlan Type]                       %let MSWPType = ahr;
*   [Workplan # 5]                        %let MSWPID = wp005 ;
*   [Unique DP id]                        %let MSDPID = nsdp ;
*   [Beta 3]                              %let MSVerID = b03 ;
*   [use underscores as delimiter]        %let dlm = _ ;
*
*   The example values above would produce a Request-ID equal to to07_nme_dabi_ahr_wp005_nsdp_b03
*
*--------------------------------------------------------------------------------------------------*/

* Specify project-ID, workplan-type, workplan-ID, workplan-type, unique-dpid, version-ID *;
%let MSProjID = test ;
%let MSWPType = qt ;
%let MSWPID   = redesign;
%let MSDPID   = dev ;    
%let MSVerID  = v2.0.1 ;
%let dlm = _ ;

* Request-ID *;
%let MSReqID = &MSProjID.&dlm.&MSWPType.&dlm.&MSWPID.&dlm.&MSDPID.&dlm.&MSVerID ;
%put &=MSReqID;

* Delete macro variable used as delimiter as we no longer need it *;
%symdel dlm ;


*-------------------------------------------------------------------------------------------------
* 0- Setup Environment
*-------------------------------------------------------------------------------------------------;

/*---------------------------------------------------------------------*/
/* NOTE: This is standard MSOC environment setup code -- Do Not Edit   */
/*---------------------------------------------------------------------*/


/*------------------------------------------------------------------------------------------------
* NOTES:
*   For reasons of compatibility and standardization, paths must meet the following criteria:
*     1- Starting with the request subdirectory, all subdirectory names must be specified in
*        lower case (for UNIX compatibility)
*     2- Slashes must be forward-leaning slashes '/' (for UNIX compatibility)
*     3- Paths must end with a final forward-leaning slash '/' (extra slashes are fine)
*------------------------------------------------------------------------------------------------*/

/* Request-ID parameter value must be lower case */
%let MSReqID = %lowcase(&MSReqID) ;

/* Define request specific subdirectories */
%let DPLOCAL = &_root_dplocal.&MSReqID./dplocal/ ;
%let MSOC = &_root_msoc.&MSReqID./msoc/ ;
%let INFOLDER = &_root_inputfiles.&MSReqID./inputfiles/ ;
%let SASPROGRAMS = &_root_sasprograms.&MSReqID./sasprograms/ ;

/* Clean up paths (e.g. convert slashes and add slashes when necessary) and validate that paths exist */
%let DPLOCAL = %ms_clean_path(&DPLOCAL) ;
%let MSOC = %ms_clean_path(&MSOC) ;
%let INFOLDER = %ms_clean_path(&INFOLDER) ;
%let SASPROGRAMS = %ms_clean_path(&SASPROGRAMS) ;

/* Assign libnames */
/* %ms_lib(libref-name, path-name, options=%str(options-name=options-value)) */
%ms_lib(dplocal, &DPLOCAL)
%ms_lib(msoc, &MSOC)
%ms_lib(infolder, &INFOLDER, options=%str(access=readonly));


**************************************************************************************************
*******                                  BEGIN PROGRAM                                     *******
**************************************************************************************************;


/*---------------------------------------------------------------------*/
/* NOTE: Programmer preparing request includes/writes                  */
/*       the rest of the program below                                 */
/*---------------------------------------------------------------------*/


*--------------------------------------------------------------------------------------------------
* 1- Include master program
*--------------------------------------------------------------------------------------------------;

** Specify the name of the master program (without any file extension);
%let _master_program_ = 001-prod_master;

** Open up new master log file for MSOC;
proc printto log="&MSOC.&_master_program_&._&DPID&SITEID..log" new;
run;

** Include Master program;
%include "&INFOLDER.&_master_program_&..sas" /source ;

* End of qt_main_program.sas;
